@@ -15,8 +15,10 @@ BEGIN {
   $Dist::Zilla::Plugin::Test::Compile::AUTHORITY = 'cpan:JQUELIN';
 }
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.032';
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.033';
 }
+# git description: v2.032-9-g57a7633
+
 # ABSTRACT: common tests to check syntax of your modules, only using core modules
 
 use Moose;
@@ -111,10 +113,10 @@ sub register_prereqs
             phase => 'test',
         },
         'Test::More' => $self->_test_more_version,
-        'Carp' => 0,
+        'File::Spec' => '0',
+        'IPC::Open3' => 0,
         'IO::Handle' => 0,
-        'File::Temp' => 0,
-        $self->_script_filenames ? ( 'File::Spec' => '0' ) : (),
+        $self->fake_home ? ( 'File::Temp' => '0' ) : (),
     );
 }
 
@@ -182,9 +184,9 @@ __PACKAGE__->meta->make_immutable;
 
 =encoding utf-8
 
-=for :stopwords Jerome Quelin Ahmad Jesse Luehrs Karen Etheridge Kent Fredric Marcel
-Gruenauer Olivier M. Mengu Peter Shangov Randy Stauner Ricardo SIGNES
-fayland Zawawi Chris Weyl Graham Knop Harley Pig cpantesters FileFinder
+=for :stopwords Jerome Quelin Ahmad Pig Jesse Luehrs Karen Etheridge Kent Fredric Marcel M.
+Gruenauer Olivier Mengu Peter Shangov Randy Stauner Ricardo SIGNES fayland
+Zawawi Chris Weyl David Golden Graham Knop Harley cpantesters FileFinder
 executables
 
 =head1 NAME
@@ -193,7 +195,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.032
+version 2.033
 
 =head1 SYNOPSIS
 
@@ -318,6 +320,10 @@ Chris Weyl <cweyl@alumni.drew.edu>
 
 =item *
 
+David Golden <dagolden@cpan.org>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
@@ -373,7 +379,7 @@ ___[ test-compile ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
+# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
 
 use Test::More {{ $test_more_version || '' }} tests => {{
     my $count = @module_filenames + @script_filenames;
@@ -418,18 +424,24 @@ CODE
     : '# no fake home requested';
 }}
 
+use File::Spec;
+use IPC::Open3;
+use IO::Handle;
+
 my @warnings;
 for my $lib (@module_files)
 {
-    my ($stdout, $stderr, $exit_code) = _capture(
-        sub {
-            system($^X, '-Mblib', '-e', "require q[$lib]");
-        }
-    );
+    # see L<perlfaq8/How can I capture STDERR from an external command?>
+    open my $stdin, '<', File::Spec->devnull or die "can't open devnull: $!";
+    my $stderr = IO::Handle->new;
 
-    is($exit_code >> 8, 0, "$lib loaded ok");
+    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, '-Mblib', '-e', "require q[$lib]");
+    binmode $stderr, ':crlf' if $^O eq 'MSWin32';
+    my @_warnings = <$stderr>;
+    waitpid($pid, 0);
+    is($? >> 8, 0, "$lib loaded ok");
 
-    if (my @_warnings = split /\n/, $stderr)
+    if (@_warnings)
     {
         warn @_warnings;
         push @warnings, @_warnings;
@@ -439,7 +451,6 @@ for my $lib (@module_files)
 {{
 @script_filenames
     ? <<'CODE'
-use File::Spec;
 foreach my $file (@scripts)
 { SKIP: {
     open my $fh, '<', $file or warn("Unable to open $file: $!"), next;
@@ -448,17 +459,18 @@ foreach my $file (@scripts)
 
     my @flags = $1 ? split(/\s+/, $1) : ();
 
-    my ($stdout, $stderr, $exit_code) = _capture(
-        sub {
-            system($^X, '-Mblib', @flags, '-c', $file);
-        }
-    );
+    open my $stdin, '<', File::Spec->devnull or die "can't open devnull: $!";
+    my $stderr = IO::Handle->new;
 
-    is($exit_code >> 8, 0, "$file compiled ok");
+    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, '-Mblib', @flags, '-c', $file);
+    binmode $stderr, ':crlf' if $^O eq 'MSWin32';
+    my @_warnings = <$stderr>;
+    waitpid($pid, 0);
+    is($? >> 8, 0, "$file compiled ok");
 
-    # in older perls, -c output is simply the file portion of the path being tested
-    if (my @_warnings = grep { !/\bsyntax OK$/ }
-        grep { chomp; $_ ne (File::Spec->splitpath($file))[2] } split /\n/, $stderr)
+   # in older perls, -c output is simply the file portion of the path being tested
+    if (@_warnings = grep { !/\bsyntax OK$/ }
+        grep { chomp; $_ ne (File::Spec->splitpath($file))[2] } @_warnings)
     {
         # temporary measure - win32 newline issues?
         warn map { _show_whitespace($_) } @_warnings;
@@ -495,76 +507,3 @@ $bail_out_on_fail
     ? 'BAIL_OUT("Compilation problems") if !Test::More->builder->is_passing;'
     : '';
 }}
-
-#--------------------------------------------------------------------------#
-# Capture::Tinier, courtesy of David Golden (see L<Capture::Tiny>)
-#--------------------------------------------------------------------------#
-
-use IO::Handle;
-use Carp;
-use File::Temp;
-
-my $IS_WIN32 = $^O eq 'MSWin32';
-
-sub _open {
-    open $_[0], $_[1] or Carp::confess "Error from open(" . join( q{, }, @_ ) . "): $!";
-}
-
-sub _close {
-    close $_[0] or Carp::confess "Error from close(" . join( q{, }, @_ ) . "): $!";
-}
-
-sub _copy_std {
-    my %handles;
-    for my $h (qw/stdout stderr stdin/) {
-        next if $h eq 'stdin' && !$IS_WIN32; # WIN32 hangs on tee without STDIN copied
-        my $redir = $h eq 'stdin' ? "<&" : ">&";
-        _open $handles{$h} = IO::Handle->new(), $redir . uc($h); # ">&STDOUT" or "<&STDIN"
-    }
-    return \%handles;
-}
-
-# In some cases we open all (prior to forking) and in others we only open
-# the output handles (setting up redirection)
-sub _open_std {
-    my ($handles) = @_;
-    _open \*STDIN,  "<&" . fileno $handles->{stdin}  if defined $handles->{stdin};
-    _open \*STDOUT, ">&" . fileno $handles->{stdout} if defined $handles->{stdout};
-    _open \*STDERR, ">&" . fileno $handles->{stderr} if defined $handles->{stderr};
-}
-
-sub _slurp {
-    my ( $name, $stash ) = @_;
-    my $fh = $stash->{new}{$name};
-    seek( $fh, 0, 0 ) or die "Couldn't seek on capture handle for $name\n";
-    my $text = do { local $/; scalar readline $fh };
-    return defined($text) ? $text : "";
-}
-
-sub _capture {
-    my ($code) = @_;
-    my $stash;
-    $stash->{old} = _copy_std();
-    $stash->{new} = { %{ $stash->{old} } }; # default to originals
-    for (qw/stdout stderr/) {
-        $stash->{new}{$_} = File::Temp->new;
-    }
-    _open_std( $stash->{new} );
-    my ( $exit_code, $inner_error, $outer_error, @result );
-    {
-        local $@;
-        eval { @result = $code->(); $inner_error = $@ };
-        $exit_code   = $?;                  # save this for later
-        $outer_error = $@;                  # save this for later
-    }
-    _open_std( $stash->{old} );
-    _close($_) for values %{ $stash->{old} }; # don't leak fds
-    my %got;
-    for (qw/stdout stderr/) {
-        $got{$_} = _slurp( $_, $stash );
-    }
-    $? = $exit_code;
-    $@ = $inner_error if $inner_error;
-    die $outer_error if $outer_error;
-    return ( $got{stdout}, $got{stderr}, @result );
-}
